@@ -213,7 +213,7 @@ add_cal_esource (EAccount *account, GSList *folders, ExchangeMAPIFolderType fold
 		conf_key = JOURNAL_SOURCES;
 		source_selection_key = SELECTED_JOURNALS;
 	} else {
-		g_warning ("%s(%d): %s: Unknown ExchangeMAPIFolderType\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+		g_warning ("%s: %s: Unknown ExchangeMAPIFolderType\n", G_STRLOC, G_STRFUNC);
 		return;
 	} 
 
@@ -323,7 +323,7 @@ remove_cal_esource (EAccount *existing_account_info, ExchangeMAPIFolderType fold
 		conf_key = JOURNAL_SOURCES;
 		source_selection_key = SELECTED_JOURNALS;
 	} else {
-		g_warning ("%s(%d): %s: Unknown ExchangeMAPIFolderType\n", __FILE__, __LINE__, __PRETTY_FUNCTION__);
+		g_warning ("%s: %s: Unknown ExchangeMAPIFolderType\n", G_STRLOC, G_STRFUNC);
 		return;
 	} 
 
@@ -456,6 +456,30 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 		g_object_unref (source);
 	}
 
+	//Add GAL
+	{
+		char *uri;
+
+		uri = g_strdup_printf("mapigal://%s@%s/;Global Address List", url->user, url->host);
+		source = e_source_new_with_absolute_uri ("Global Address List", uri);
+		// source = e_source_new ("Global Address List", g_strconcat (";","Global Address List" , NULL));
+		e_source_set_property (source, "auth", "plain/password");
+		e_source_set_property (source, "auth-domain", "MAPIGAL");
+
+		//FIXME: Offline handling
+		e_source_set_property(source, "user", url->user);
+		e_source_set_property(source, "host", camel_url_get_param (url, "ad_server"));
+		e_source_set_property(source, "view-limit", camel_url_get_param (url, "ad_limit"));
+		e_source_set_property(source, "profile", camel_url_get_param (url, "profile"));
+		e_source_set_property(source, "domain", camel_url_get_param (url, "domain"));
+		// e_source_set_property (source, "offline_sync",
+		// camel_url_get_param (url, "offline_sync") ? "1" : "0");
+		e_source_set_property(source, "offline_sync", "1");
+		e_source_set_property (source, "completion", "true");
+		e_source_group_add_source (group, source, -1);
+		g_object_unref (source);
+	}
+
 	e_source_list_add_group (list, group, -1);
 	e_source_list_sync (list, NULL);
 	g_object_unref (group);
@@ -598,7 +622,7 @@ create_profile_entry (CamelURL *url)
 		g_free (key);
 
 		if (password)
-			status = exchange_mapi_create_profile (url->user, password, camel_url_get_param (url, "domain"), url->host);
+		  status = exchange_mapi_create_profile (url->user, password, camel_url_get_param (url, "domain"), url->host, NULL, NULL, NULL);
 
 		++attempts; 
 	}
@@ -606,19 +630,28 @@ create_profile_entry (CamelURL *url)
 	return status; 
 }
 
+static gboolean
+check_equal (const char *a, const char *b)
+{
+	if (!a && a == b)
+		return TRUE;
+
+	return a && b && g_ascii_strcasecmp (a, b) == 0;
+}
+
 static gboolean
 mapi_camel_url_equal (CamelURL *a, CamelURL *b)
 {
-	const char *params[] = { "profile", "domain", "ad_limit", "ad_server" }; 
-	guint n_params = G_N_ELEMENTS (params), i; 
-	gboolean retval = TRUE; 
+	const char *params[] = { "profile", "domain", "ad_limit", "ad_server" };
+	guint n_params = G_N_ELEMENTS (params), i;
+	gboolean retval = TRUE;
 
-	retval &= camel_url_equal (a, b); 
+	retval = camel_url_equal (a, b);
 
-	for (i = 0; i < n_params; ++i)
-		retval &= (g_ascii_strcasecmp (camel_url_get_param (a, params[i]), camel_url_get_param (b, params[i])) == 0);
+	for (i = 0; retval && i < n_params; ++i)
+		retval = retval && check_equal (camel_url_get_param (a, params[i]), camel_url_get_param (b, params[i]));
 
-	return retval; 
+	return retval;
 }
 
 static void
