@@ -33,10 +33,11 @@ typedef enum {
 	MAPI_OPTIONS_FETCH_ATTACHMENTS = 1<<0,
 	MAPI_OPTIONS_FETCH_RECIPIENTS = 1<<1,
 	MAPI_OPTIONS_FETCH_BODY_STREAM = 1<<2,
-	MAPI_OPTIONS_FETCH_GENERIC_STREAMS = 1<<3, 
-	MAPI_OPTIONS_DONT_SUBMIT = 1<<4, 
-	MAPI_OPTIONS_GETBESTBODY = 1<<5,
-	MAPI_OPTIONS_USE_PFSTORE = 1<<6
+	MAPI_OPTIONS_FETCH_GENERIC_STREAMS = 1<<3,
+	MAPI_OPTIONS_FETCH_GAL = 1 <<4,
+	MAPI_OPTIONS_DONT_SUBMIT = 1<<5, 
+	MAPI_OPTIONS_GETBESTBODY = 1<<6,
+	MAPI_OPTIONS_USE_PFSTORE = 1<<7
 } ExchangeMAPIOptions;
 
 #define MAPI_OPTIONS_FETCH_ALL MAPI_OPTIONS_FETCH_ATTACHMENTS | \
@@ -44,6 +45,7 @@ typedef enum {
 	                       MAPI_OPTIONS_FETCH_BODY_STREAM | \
 	                       MAPI_OPTIONS_FETCH_GENERIC_STREAMS
 
+
 typedef struct {
 	GByteArray *value;
 	uint32_t proptag;
@@ -58,6 +60,7 @@ typedef struct {
 typedef struct {
 	/* MANDATORY */
 	const char *email_id;
+	TALLOC_CTX *mem_ctx;
 
 	/* It is ideal to set all these properties on all recipients 
 	 * as we never know if a recipient would be resolved or not. */ 
@@ -81,6 +84,11 @@ typedef struct {
 	} out; 
 } ExchangeMAPIRecipient;
 
+typedef struct {
+	const char *name;
+	const char *email;
+} ExchangeMAPIGALEntry;
+
 typedef struct {
 	uint32_t cValues; 
 	struct SPropValue *lpProps; 
@@ -94,6 +102,7 @@ typedef struct {
 	mapi_id_t mid;
 	GSList *attachments;
 	GSList *recipients;
+	GSList *gallist;
 	GSList *streams;
 	guint total; /*Total number of results*/
 	guint index; /*Index of this Item*/
@@ -130,6 +139,9 @@ exchange_mapi_connection_fetch_items   (mapi_id_t fid,
 					FetchCallback cb, gpointer data, 
 					guint32 options);
 
+gboolean
+exchange_mapi_util_get_gal (GPtrArray *contacts_array);
+
 mapi_id_t 
 exchange_mapi_create_folder (uint32_t olFolder, mapi_id_t pfid, const char *name);
 
@@ -175,7 +187,7 @@ exchange_mapi_move_items ( mapi_id_t src_fid, mapi_id_t dest_fid, GSList *mids);
 
 
 gboolean exchange_mapi_get_folders_list (GSList **mapi_folders); 
-gboolean exchange_mapi_get_pf_folders_list (GSList **mapi_folders); 
+gboolean exchange_mapi_get_pf_folders_list (GSList **mapi_folders, mapi_id_t parent_id); 
 
 struct SPropTagArray *
 exchange_mapi_util_resolve_named_props (uint32_t olFolder, mapi_id_t fid, 
@@ -187,7 +199,9 @@ uint32_t
 exchange_mapi_util_create_named_prop (uint32_t olFolder, mapi_id_t fid, 
 				      const char *named_prop_name, uint32_t ptype);
 
-gboolean exchange_mapi_create_profile (const char *username, const char *password, const char *domain, const char *server, char **error_msg);
+gboolean exchange_mapi_create_profile (const char *username, const char *password,
+				       const char *domain, const char *server,
+				       char **error_msg, mapi_profile_callback_t cb, gpointer data);
 gboolean exchange_mapi_delete_profile (const char *profile);
 
 #endif
