@@ -55,6 +55,8 @@ utf8tolinux (const char *wstring)
 
 	if (g_utf8_validate (newstr, -1, NULL)) 
 		retval = g_strdup (newstr);
+	else
+		retval = g_strdup (wstring);
 
 	talloc_free (mem_ctx);
 
@@ -262,6 +264,8 @@ exchange_mapi_util_free_recipient_list (GSList **recip_list)
 
 	for (; l != NULL; l = l->next) {
 		ExchangeMAPIRecipient *recipient = (ExchangeMAPIRecipient *) (l->data);
+
+		talloc_free (recipient->mem_ctx);
 		if (recipient->in.ext_cValues)
 			g_free (recipient->in.ext_lpProps);
 		if (recipient->in.req_cValues)
